// SelectLanguageDlg.h
// (c) 2003-2005 exeal

#ifndef _SELECT_LANGUAGE_DLG_H_
#define _SELECT_LANGUAGE_DLG_H_
#include "resource.h"
#include "../Manah/Dialog.h"


namespace Alpha {
	///	[GW̑I] _CAO
	class CSelectLanguageDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_SELECTLANGUAGE> {
		// \bh
	public:
		std::wstring	GetSelectedLanguage() const;

		// bZ[Wnh
	protected:
		virtual bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);	// WM_COMMAND
		virtual bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);		// WM_INITDIALOG
		virtual void	OnOK();													// IDOK

		// f[^o
	private:
		std::wstring	m_strSelectedLanguage;
	};

	///	IꂽԂ
	inline std::wstring CSelectLanguageDlg::GetSelectedLanguage() const {
		return m_strSelectedLanguage;
	}
}

#endif /* _SELECT_LANGUAGE_DLG_H_ */

/* [EOF] */